'use strict';

define([
        'underscore',
        'jquery',
        'module',
        'routing',
        'pim/form/common/save',
        'text!pim/template/form/save'
    ],
    function(
        _,
        $,
        module,
        Routing,
        SaveForm,
        template
    ) {
        return SaveForm.extend({
            template: _.template(template),
            events: {
                'click .save': 'save'
            },

            /**
             * {@inheritdoc}
             */
            render: function () {
                this.$el.html(this.template({
                    label: _.__('pim_enrich.entity.save.label')
                }));
            },

            /**
             * {@inheritdoc}
             */
            save: function () {
                this.getRoot().trigger('pim_enrich:form:entity:pre_save', this.getFormData());
                this.showLoadingMask();

                $.ajax({
                    method: 'POST',
                    url: this.getSaveUrl(),
                    contentType: 'application/json',
                    data: JSON.stringify(this.getFormData())
                })
                .then(this.postSave.bind(this))
                .fail(this.fail.bind(this))
                .always(this.hideLoadingMask.bind(this));
            },

            /**
             * {@inheritdoc}
             */
            getSaveUrl: function () {
                return Routing.generate(module.config().route);
            },

            /**
             * {@inheritdoc}
             */
            postSave: function (data) {
                this.setData(data);

                SaveForm.prototype.postSave.apply(this, arguments);
            }
        });
    }
);
